Package: SBMLR
Title: SBML-R Interface and Analysis Tools
Version: 2.8.0
Date: 2022-03-28
Author: Tomas Radivoyevitch, Vishak Venkateswaran
Description: This package contains a systems biology markup language
        (SBML) interface to R.
Maintainer: Tomas Radivoyevitch <radivot@gmail.com>
Depends: XML, deSolve
Suggests: rsbml
License: GPL-2
URL: http://epbi-radivot.cwru.edu/SBMLR/SBMLR.html
biocViews: GraphAndNetwork, Pathways, Network
git_url: https://git.bioconductor.org/packages/SBMLR
git_branch: RELEASE_3_23
git_last_commit: d915c8a
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:22:58 UTC; biocbuild
Built: R 4.6.0; ; 2026-04-29 19:32:17 UTC; unix
