Although I update these files (for the first time since 2005) to use sim() instead of simulate(), 
these codes depend on R data packages that I once maintained but no longer do. 
As such, I'm keeping this code here just so I can look
back at the source if I need to, i.e. I'm no longer maintaining these files
as an example of reproducible research. 